% init_EBAY_gen based on init_BARROW_gen
% Pat Wongpan, 12 October 2016

clear variables;
close all;
clc;
% COPY FILE
copyfile(which('init_BARROW.nc'),'init_EBAY.nc');
fileattrib('init_EBAY.nc','+w');
% EDIT GLOBAL
ncwriteatt('init_EBAY.nc','/','DATE',datestr(now));
ncwriteatt('init_EBAY.nc','/','comments','Initialization file for Erebus Bay (EBAY), Pat Wongpan and Martin Vancoppenolle, October 2016')
ncdisp('init_EBAY.nc');
%=================================================================
% Source:
%            /Users/patwongpan/Dropbox/LIM1D/LIM1D_v3.20_paris/INPUT/EBAY/init_EBAY.nc
% Format:
%            classic
% Global Attributes:
%            DATE     = '12-Oct-2016 12:02:36'
%            version  = '1.0'
%            comments = 'Initialization file for Erebus Bay (EBAY), Pat Wongpan and Martin Vancoppenolle, October 2016'
% Dimensions:
%            N      = 16
%            scalar = 1
%=================================================================
% Variables:
%=================================================================
%     nlay
%            Size:       1x1
%            Dimensions: scalar
%            Datatype:   int16
%            Attributes:
%                        LONGNAME = 'Number of layers'
%                        UNITS    = '-'
%>>> READ
nlay_R = ncread('init_EBAY.nc','nlay');
%-
nlay = nlay_R; % NO CHANGE
%-
%<<< WRITE
%ncwrite('init_EBAY.nc','nlay',nlay);
%=================================================================
%     j_d 
%            Size:       1x1
%            Dimensions: scalar
%            Datatype:   single
%            Attributes:
%                        LONGNAME = 'julian day'
%                        UNITS    = 'd'
%>>> READ
j_d_R = ncread('init_EBAY.nc','j_d');
%-
formation_date = datenum('28-Apr-2009,00:00','dd-mmm-yyyy,HH:MM'); % Formation date
first_day = datenum('01-Jan-2009,00:00','dd-mmm-yyyy,HH:MM');
j_d = formation_date - first_day;
%-
%<<< WRITE
ncwrite('init_EBAY.nc','j_d',j_d);
%=================================================================
%     h_s 
%            Size:       1x1
%            Dimensions: scalar
%            Datatype:   single
%            Attributes:
%                        LONGNAME = 'snow depth'
%                        UNITS    = 'm'
%>>> READ
h_s_R = ncread('init_EBAY.nc','h_s'); %0.1145
%-
h_s = 0.0; % no snow
%-
%<<< WRITE
ncwrite('init_EBAY.nc','h_s',h_s);
%=================================================================
%     t_s 
%            Size:       1x1
%            Dimensions: scalar
%            Datatype:   single
%            Attributes:
%                        LONGNAME = 'snow temperature'
%                        UNITS    = 'K'
%>>> READ
t_s_R = ncread('init_EBAY.nc','t_s');
%-
t_s = t_s_R; % NO CHANGE
%-
%<<< WRITE
ncwrite('init_EBAY.nc','t_s',t_s);
%=================================================================
%     t_su
%            Size:       1x1
%            Dimensions: scalar
%            Datatype:   single
%            Attributes:
%                        LONGNAME = 'surface temperature'
%                        UNITS    = 'K'
%>>> READ
t_su_R = ncread('init_EBAY.nc','t_su');
%-
t_su_Celcius = -20.0;
t_su = 273.15 + t_su_Celcius;
%-
%<<< WRITE
%ncwrite('init_EBAY.nc','t_su',t_su);
%=================================================================
%     h_i 
%            Size:       1x1
%            Dimensions: scalar
%            Datatype:   single
%            Attributes:
%                        LONGNAME = 'ice thickness'
%                        UNITS    = 'm'
%>>> READ
h_i_R = ncread('init_EBAY.nc','h_i');
%-
h_i_cm = 5.0; % 5 [cm]
h_i = h_i_cm/100.0; % [m]
%-
%<<< WRITE
ncwrite('init_EBAY.nc','h_i',h_i);
%=================================================================
%     z_i 
%            Size:       16x1
%            Dimensions: N
%            Datatype:   single
%            Attributes:
%                        LONGNAME = 'depth in the ice'
%                        UNITS    = 'm'
%>>> READ
z_i_R = ncread('init_EBAY.nc','z_i');
%-
z_i_max = h_i; %[m]
%z_i = linspace(0.01,z_i_max,nlay); % [m]
z_i = ones(16,1).*z_i_max;
%-
%<<< WRITE
ncwrite('init_EBAY.nc','z_i',z_i');
%=================================================================
%     t_i 
%            Size:       16x1
%            Dimensions: N
%            Datatype:   single
%            Attributes:
%                        LONGNAME = 'ice temperatures'
%                        UNITS    = 'K'
%>>> READ
t_i_R = ncread('init_EBAY.nc','t_i');
%-
t_i_air = t_su; % surface temperature [K]
t_i_oce_Celcius = -1.80;
t_i_oce = 273.15 + t_i_oce_Celcius;
t_i = linspace(t_i_air,t_i_oce,nlay);
%-
%<<< WRITE
ncwrite('init_EBAY.nc','t_i',t_i');
%=================================================================
%     s_i 
%            Size:       16x1
%            Dimensions: N
%            Datatype:   single
%            Attributes:
%                        LONGNAME = 'ice salinities'
%                        UNITS    = 'psu'
%>>> READ
s_i_R = ncread('init_EBAY.nc','s_i');
%-
s_i = 4.606 + 0.91603./z_i; %[z_i in m]
%-
%<<< WRITE
ncwrite('init_EBAY.nc','s_i',s_i);
%=================================================================