      SUBROUTINE ice_brine   

!------------------------------------------------------------------------------!
!                               *** ice_brine    ***
!
!     This routine computes brine density (kg/m3) and salinity (g/kg)
!     from K-temperature
!     in each vertical layer
!
!     Refs: Notz (2005) and Vancoppenolle et al (TCD 2015)
!
!------------------------------------------------------------------------------!

      USE lib_fortran

      INCLUDE 'type.com'
      INCLUDE 'para.com'
      INCLUDE 'const.com'
      INCLUDE 'ice.com'
      INCLUDE 'thermo.com'
      INCLUDE 'bio.com'
      INCLUDE 'tank.com'

!==============================================================================!

!
!------------------------------------------------------------------------------!
! X) Starting the routine
!------------------------------------------------------------------------------!
!

      WRITE(numout,*)
      WRITE(numout,*) ' *** ice_brine : '
      WRITE(numout,*) ' ~~~~~~~~~~~~~~~~'
      WRITE(numout,*)

!
!------------------------------------------------------------------------------!
! X) Brine characteristics
!------------------------------------------------------------------------------!
!
         
      DO layer = 1, nlay_bio
         
         tc_bio(layer)    = t_i_bio(layer) - 273.15                     ! Temperature in celsius
         zt2 = tc_bio(layer) * tc_bio(layer)
         zt3 = tc_bio(layer) * zt2
         
         sbr_bio(layer)   = -21.4*tc_bio(layer) - 0.886*zt2 -0.0107*zt3 ! Brine 3rd order salinity
         
         rhobr_bio(layer) = rho0 + beta_ocs*( sbr_bio(layer)-s_w )  ! Brine density
            
      END DO

!
!------------------------------------------------------------------------------!
! X) End of the routine
!------------------------------------------------------------------------------!
!
      WRITE(numout,*)
      WRITE(numout,*) ' End of ice_brine '
      WRITE(numout,*) '~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~'
      WRITE(numout,*)
     
      RETURN

      END
